==> kadu_3.0.orig.tar.bz2: kadu-3.0/plugins/encryption_otr/translations/encryption_otr_es_MX.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>OTR Encryption</source>
        <translation>Cifrado OTR</translation>
    </message>
    <message>
        <source>Create private key started</source>
        <translation>Se inició la creación de la clave privada</translation>
    </message>
    <message>
        <source>Create private key finished</source>
        <translation>Se terminó la creación de la clave privada</translation>
    </message>
</context>
<context>
    <name>OtrAccountConfigurationWidget</name>
    <message>
        <source>Enable private messaging</source>
        <translation>Habilitar mensajería privada</translation>
    </message>
    <message>
        <source>Automatically initiate private messaging</source>
        <translation>Iniciar automáticamente mensajería privada</translation>
    </message>
    <message>
        <source>Require private messaging</source>
        <translation>Requerir mensajería privada</translation>
    </message>
    <message>
        <source>OTR Encryption</source>
        <translation>Cifrado OTR</translation>
    </message>
</context>
<context>
    <name>OtrBuddyConfigurationWidget</name>
    <message>
        <source>Use account&apos;s policy</source>
        <translation>Usar la política de cuenta</translation>
    </message>
    <message>
        <source>Enable private messaging</source>
        <translation>Habilitar mensajería privada</translation>
    </message>
    <message>
        <source>Automatically initiate private messaging</source>
        <translation>Iniciar automáticamente mensajería privada</translation>
    </message>
    <message>
        <source>Require private messaging</source>
        <translation>Requerir mensajería privada</translation>
    </message>
    <message>
        <source>OTR Encryption</source>
        <translation>Cifrado OTR</translation>
    </message>
</context>
<context>
    <name>OtrChatTopBarWidget</name>
    <message>
        <source>Start Private Conversation</source>
        <translation>Iniciar Conversación Privada</translation>
    </message>
    <message>
        <source>End Private Conversation</source>
        <translation>Terminar Conversación Privada</translation>
    </message>
    <message>
        <source>Verify Peer Identity</source>
        <translation>Verificar Identidad del Par</translation>
    </message>
    <message>
        <source>Refresh Private Conversation</source>
        <translation>Actualizar conversación privada</translation>
    </message>
    <message>
        <source>Unverified</source>
        <translation>No verificado</translation>
    </message>
    <message>
        <source>Private</source>
        <translation>Privado</translation>
    </message>
    <message>
        <source>Not Private</source>
        <translation>No Privado</translation>
    </message>
</context>
<context>
    <name>OtrErrorMessageService</name>
    <message>
        <source>Error occurred during message encryption</source>
        <translation>Se produjo un error durante el cifrado de mensajes</translation>
    </message>
    <message>
        <source>You sent encrypted data to %1, who wasn&apos;t expecting it</source>
        <translation>Usted envió datos cifrados a %1, que no se lo esperaba</translation>
    </message>
    <message>
        <source>You transmitted an unreadable encrypted message</source>
        <translation>Usted transmitió un mensaje cifrado ilegible</translation>
    </message>
    <message>
        <source>You transmitted a malformed data message</source>
        <translation>Usted transmitió un mensaje mal formado</translation>
    </message>
</context>
<context>
    <name>OtrMessageEventService</name>
    <message>
        <source>Unencrypted messages to %1 are not allowed. Attmpting to start a private conversation...</source>
        <translation>Los mensajes sin cifrar para %1 no están permitidos. Intentando iniciar una conversación privada...</translation>
    </message>
    <message>
        <source>Encryption error. Message was not sent.</source>
        <translation>Error de cifrado. El mensaje no fue enviado.</translation>
    </message>
    <message>
        <source>Message was not sent. Private conversation was closed by %1. Either restart or close your private conversation.</source>
        <translation>El mensaje no fue enviado. La conversación privada fue cerrada por %1. Reinicie o cierre su conversación privada.</translation>
    </message>
    <message>
        <source>Error during setting up private conversation with %1: %2</source>
        <translation>Error durante la creación de la conversación privada con %1: %2</translation>
    </message>
    <message>
        <source>We are receiving our own OTR messages from %1. Either restart or close your private conversation.</source>
        <translation>Estamos recibiendo nuestros propios mensajes OTR de %1. Reinicie o cierre su conversación privada.</translation>
    </message>
    <message>
        <source>Last message was resent: %1</source>
        <translation>El último mensaje fue reenviado: %1</translation>
    </message>
    <message>
        <source>Message from %1 was unreadable, as you are not currently communicating privately.</source>
        <translation>El mensaje de %1 era ilegible, ya que usted no está comunicandose de forma privada.</translation>
    </message>
    <message>
        <source>Message from %1 was unreadable.</source>
        <translation>El mensaje de %1 era ilegible.</translation>
    </message>
    <message>
        <source>Message from %1 was malformed.</source>
        <translation>El mensaje de %1 estaba mal formado.</translation>
    </message>
    <message>
        <source>Encryption error: %1</source>
        <translation>Error de cifrado: %1</translation>
    </message>
    <message>
        <source>Message from %1 was unencrypted.</source>
        <translation>El mensaje de %1 no estaba cifrado.</translation>
    </message>
    <message>
        <source>Message from %1 was unrecognized.</source>
        <translation>El mensaje de %1 no fue reconocido.</translation>
    </message>
    <message>
        <source>%1 has sent a message intended for different session. If you are logged in multiple times another session may have received the message.</source>
        <translation>%1 ha enviado un mensaje destinado para diferentes sesiones. Si inició sesión en multiples ocasiones otra sesión puede haber recibido el mensaje.</translation>
    </message>
    <message>
        <source>Malformed message received</source>
        <translation>Mensaje mal formado recibido</translation>
    </message>
</context>
<context>
    <name>OtrMessageService</name>
    <message>
        <source>[resent]</source>
        <translation>[reenviado]</translation>
    </message>
</context>
<context>
    <name>OtrNotifier</name>
    <message>
        <source>OTR Encryption</source>
        <translation>Cifrado OTR</translation>
    </message>
    <message>
        <source>%1: trying to start private conversation</source>
        <translation>%1: tratando de iniciar conversación privada</translation>
    </message>
    <message>
        <source>%1: trying to refresh private conversation</source>
        <translation>%1: tratando de actualizar conversación privada</translation>
    </message>
    <message>
        <source>%1: peer ended private conversation; you should do the same</source>
        <translation>%1: el par terminó la conversación privadad; usted debe hacer lo mismo</translation>
    </message>
    <message>
        <source>%1: private conversation started</source>
        <translation>%1: conversación privada iniciada</translation>
    </message>
    <message>
        <source>%1: private conversation stopped</source>
        <translation>%1: conversación privada detenida</translation>
    </message>
    <message>
        <source>%1: conversation is still private</source>
        <translation>%1: la conversación sigue siendo privada</translation>
    </message>
    <message>
        <source>%1: creating private key, it can took a few minutes</source>
        <translation>%1: creando la clave privada, puede tardar unos minutos</translation>
    </message>
    <message>
        <source>%1: private key created, you can start a private conversation now</source>
        <translation>%1: clave privada creada, puede empezar una conversación privada ahora</translation>
    </message>
    <message>
        <source>%1: private key creation failed</source>
        <translation>%1: la creación de la clave privada falló</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationFingerprintExchangePage</name>
    <message>
        <source>Fingerprint Exchange</source>
        <translation>Intercambio de Huella</translation>
    </message>
    <message>
        <source>Your Key Fingerprint (%1: %2):</source>
        <translation>Su Huella de Clave (%1: %2):</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; Key Fingerprint (%2: %3):</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; Huella de la Clave (%2: %3):</translation>
    </message>
    <message>
        <source>I&apos;m not sure if above Key Fingerprint belongs to %1</source>
        <translation>No estoy seguro si la Huella de la Clave pertenece a %1</translation>
    </message>
    <message>
        <source>I confirm that above Key Fingerprint belongs to %1</source>
        <translation>Confirmo que la Huella de la Clave pertenece a %1</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationProgressPage</name>
    <message>
        <source>Verification Progress</source>
        <translation>Progreso de Verificación</translation>
    </message>
    <message>
        <source>Verification in progres...</source>
        <translation>Verificación en progreso...</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationQuestionAndAnswerPage</name>
    <message>
        <source>Ask Question</source>
        <translation>Hacer pregunta</translation>
    </message>
    <message>
        <source>Question and Answer</source>
        <translation>Pregunta y Respuesta</translation>
    </message>
    <message>
        <source>Question that only %1 can answer:</source>
        <translation>Pregunta que sólo %1 puede responder:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Respuesta:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationRespondQuestionAndAnswerPage</name>
    <message>
        <source>Answer Question</source>
        <translation>Contestar pregunta</translation>
    </message>
    <message>
        <source>Respond to Question and Answer</source>
        <translation>Responder a Pregunta y Respuesta</translation>
    </message>
    <message>
        <source>%1 wants to verify your identity using Question and Answer method.</source>
        <translation>%1 quiere verificar su identidad usando el método de Pregunta y Respuesta.</translation>
    </message>
    <message>
        <source>%1 question:</source>
        <translation>%1 pregunta:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Respuesta:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationRespondSharedSecretPage</name>
    <message>
        <source>Send Shared Secret</source>
        <translation>Enviar secreto compartido</translation>
    </message>
    <message>
        <source>Respond to Shared Secret</source>
        <translation>Responder al secreto compartido</translation>
    </message>
    <message>
        <source>%1 wants to verify your identity using Shared Secret method.</source>
        <translation>%1 quiere verificar su identidad usando el método de Secreto Compartido.</translation>
    </message>
    <message>
        <source>Shared Secret that is known only for you and %1:</source>
        <translation>Secreto Compartido que se conoce sólo por usted y %1:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationResultPage</name>
    <message>
        <source>Verification Result</source>
        <translation>Resultado de verificación</translation>
    </message>
    <message>
        <source>Verificationof %1 failed. You are probably talking to an imposter. Either close conversation or try other verification method.</source>
        <translation>La verificación de %1 falló. Usted probablemente está hablando con un impostor. Cierre la conversación o intente otro método de verificación.</translation>
    </message>
    <message>
        <source>%1 has verified you. You should do the same.</source>
        <translation>%1 te ha verificado. Usted debe hacer lo mismo.</translation>
    </message>
    <message>
        <source>Verification of %1 succeeded.</source>
        <translation>La verificación de %1 tuvo éxito.</translation>
    </message>
    <message>
        <source>Unknown.</source>
        <translation>Desconocido.</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationSelectMethodPage</name>
    <message>
        <source>Select Verification Method</source>
        <translation>Seleccionar método de verificación</translation>
    </message>
    <message>
        <source>Question and Answer</source>
        <translation>Pregunta y Respuesta</translation>
    </message>
    <message>
        <source>Shared Secred</source>
        <translation>Secreto compartido</translation>
    </message>
    <message>
        <source>Fingerprint Exchange</source>
        <translation>Intercambio de Huella</translation>
    </message>
    <message>
        <source>Ask peer a question that only you and he/she know the answer for. If your peer answer it properly, he/she will be marked as verified.</source>
        <translation>Hacer una pregunta al par que sólo usted y él/ella conocen la respuesta. Si su par la responde correctamente, él/ella estará marcado como verificado.</translation>
    </message>
    <message>
        <source>Exchange a secret message with peer. This message should be agreed to on another secure channel (face-to-face conversation or a phone).</source>
        <translation>Intercambiar un mensaje secreto con el par. Este mensaje debe ser acordado en otro canal seguro (conversación cara a cara o por teléfono).</translation>
    </message>
    <message>
        <source>Check your peer&apos;s fingerprint manually. Fingreprint information shoud be exchanged on another secure channel (face-to-face conversation or a phone).</source>
        <translation>Compruebe la huella de su par manualmente. La informacion de la huella debe ser intercambiada en otro canal seguro (conversación cara a cara o por teléfono).</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationSharedSecretPage</name>
    <message>
        <source>Ask for Shared Secret</source>
        <translation>Solicitar Secreto Compartido</translation>
    </message>
    <message>
        <source>Shared Secret</source>
        <translation>Secreto Compartido</translation>
    </message>
    <message>
        <source>Shared Secret that is known only for you and %1:</source>
        <translation>Secreto Compartido que se conoce sólo por usted y %1:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationWindow</name>
    <message>
        <source>Verify Identity of %1</source>
        <translation>Verificar la Identidad de %1</translation>
    </message>
</context>
</TS>

==> kadu_4.1.orig.tar.bz2: kadu-4.1/plugins/encryption_otr/translations/encryption_otr_es_MX.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_MX" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>OTR Encryption</source>
        <translation>Cifrado OTR</translation>
    </message>
    <message>
        <source>Create private key started</source>
        <translation>Se inició la creación de la clave privada</translation>
    </message>
    <message>
        <source>Create private key finished</source>
        <translation>Se terminó la creación de la clave privada</translation>
    </message>
</context>
<context>
    <name>OtrAccountConfigurationWidget</name>
    <message>
        <source>Enable private messaging</source>
        <translation>Habilitar mensajería privada</translation>
    </message>
    <message>
        <source>Automatically initiate private messaging</source>
        <translation>Iniciar automáticamente mensajería privada</translation>
    </message>
    <message>
        <source>Require private messaging</source>
        <translation>Requerir mensajería privada</translation>
    </message>
    <message>
        <source>OTR Encryption</source>
        <translation>Cifrado OTR</translation>
    </message>
</context>
<context>
    <name>OtrBuddyConfigurationWidget</name>
    <message>
        <source>Use account&apos;s policy</source>
        <translation>Usar la política de cuenta</translation>
    </message>
    <message>
        <source>Enable private messaging</source>
        <translation>Habilitar mensajería privada</translation>
    </message>
    <message>
        <source>Automatically initiate private messaging</source>
        <translation>Iniciar automáticamente mensajería privada</translation>
    </message>
    <message>
        <source>Require private messaging</source>
        <translation>Requerir mensajería privada</translation>
    </message>
    <message>
        <source>OTR Encryption</source>
        <translation>Cifrado OTR</translation>
    </message>
</context>
<context>
    <name>OtrChatTopBarWidget</name>
    <message>
        <source>Start Private Conversation</source>
        <translation>Iniciar Conversación Privada</translation>
    </message>
    <message>
        <source>End Private Conversation</source>
        <translation>Terminar Conversación Privada</translation>
    </message>
    <message>
        <source>Verify Peer Identity</source>
        <translation>Verificar Identidad del Par</translation>
    </message>
    <message>
        <source>Refresh Private Conversation</source>
        <translation>Actualizar conversación privada</translation>
    </message>
    <message>
        <source>Unverified</source>
        <translation>No verificado</translation>
    </message>
    <message>
        <source>Private</source>
        <translation>Privado</translation>
    </message>
    <message>
        <source>Not Private</source>
        <translation>No Privado</translation>
    </message>
</context>
<context>
    <name>OtrErrorMessageService</name>
    <message>
        <source>Error occurred during message encryption</source>
        <translation>Se produjo un error durante el cifrado de mensajes</translation>
    </message>
    <message>
        <source>You sent encrypted data to %1, who wasn&apos;t expecting it</source>
        <translation>Usted envió datos cifrados a %1, que no se lo esperaba</translation>
    </message>
    <message>
        <source>You transmitted an unreadable encrypted message</source>
        <translation>Usted transmitió un mensaje cifrado ilegible</translation>
    </message>
    <message>
        <source>You transmitted a malformed data message</source>
        <translation>Usted transmitió un mensaje mal formado</translation>
    </message>
</context>
<context>
    <name>OtrMessageEventService</name>
    <message>
        <source>Unencrypted messages to %1 are not allowed. Attmpting to start a private conversation...</source>
        <translation>Los mensajes sin cifrar para %1 no están permitidos. Intentando iniciar una conversación privada...</translation>
    </message>
    <message>
        <source>Encryption error. Message was not sent.</source>
        <translation>Error de cifrado. El mensaje no fue enviado.</translation>
    </message>
    <message>
        <source>Message was not sent. Private conversation was closed by %1. Either restart or close your private conversation.</source>
        <translation>El mensaje no fue enviado. La conversación privada fue cerrada por %1. Reinicie o cierre su conversación privada.</translation>
    </message>
    <message>
        <source>Error during setting up private conversation with %1: %2</source>
        <translation>Error durante la creación de la conversación privada con %1: %2</translation>
    </message>
    <message>
        <source>We are receiving our own OTR messages from %1. Either restart or close your private conversation.</source>
        <translation>Estamos recibiendo nuestros propios mensajes OTR de %1. Reinicie o cierre su conversación privada.</translation>
    </message>
    <message>
        <source>Last message was resent: %1</source>
        <translation>El último mensaje fue reenviado: %1</translation>
    </message>
    <message>
        <source>Message from %1 was unreadable, as you are not currently communicating privately.</source>
        <translation>El mensaje de %1 era ilegible, ya que usted no está comunicandose de forma privada.</translation>
    </message>
    <message>
        <source>Message from %1 was unreadable.</source>
        <translation>El mensaje de %1 era ilegible.</translation>
    </message>
    <message>
        <source>Message from %1 was malformed.</source>
        <translation>El mensaje de %1 estaba mal formado.</translation>
    </message>
    <message>
        <source>Encryption error: %1</source>
        <translation>Error de cifrado: %1</translation>
    </message>
    <message>
        <source>Message from %1 was unencrypted.</source>
        <translation>El mensaje de %1 no estaba cifrado.</translation>
    </message>
    <message>
        <source>Message from %1 was unrecognized.</source>
        <translation>El mensaje de %1 no fue reconocido.</translation>
    </message>
    <message>
        <source>%1 has sent a message intended for different session. If you are logged in multiple times another session may have received the message.</source>
        <translation>%1 ha enviado un mensaje destinado para diferentes sesiones. Si inició sesión en multiples ocasiones otra sesión puede haber recibido el mensaje.</translation>
    </message>
    <message>
        <source>Malformed message received</source>
        <translation>Mensaje mal formado recibido</translation>
    </message>
</context>
<context>
    <name>OtrMessageService</name>
    <message>
        <source>[resent]</source>
        <translation>[reenviado]</translation>
    </message>
</context>
<context>
    <name>OtrNotifier</name>
    <message>
        <source>OTR Encryption</source>
        <translation>Cifrado OTR</translation>
    </message>
    <message>
        <source>%1: trying to start private conversation</source>
        <translation>%1: tratando de iniciar conversación privada</translation>
    </message>
    <message>
        <source>%1: trying to refresh private conversation</source>
        <translation>%1: tratando de actualizar conversación privada</translation>
    </message>
    <message>
        <source>%1: peer ended private conversation; you should do the same</source>
        <translation>%1: el par terminó la conversación privadad; usted debe hacer lo mismo</translation>
    </message>
    <message>
        <source>%1: private conversation started</source>
        <translation>%1: conversación privada iniciada</translation>
    </message>
    <message>
        <source>%1: private conversation stopped</source>
        <translation>%1: conversación privada detenida</translation>
    </message>
    <message>
        <source>%1: conversation is still private</source>
        <translation>%1: la conversación sigue siendo privada</translation>
    </message>
    <message>
        <source>%1: creating private key, it can took a few minutes</source>
        <translation>%1: creando la clave privada, puede tardar unos minutos</translation>
    </message>
    <message>
        <source>%1: private key created, you can start a private conversation now</source>
        <translation>%1: clave privada creada, puede empezar una conversación privada ahora</translation>
    </message>
    <message>
        <source>%1: private key creation failed</source>
        <translation>%1: la creación de la clave privada falló</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationFingerprintExchangePage</name>
    <message>
        <source>Fingerprint Exchange</source>
        <translation>Intercambio de Huella</translation>
    </message>
    <message>
        <source>Your Key Fingerprint (%1: %2):</source>
        <translation>Su Huella de Clave (%1: %2):</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; Key Fingerprint (%2: %3):</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; Huella de la Clave (%2: %3):</translation>
    </message>
    <message>
        <source>I&apos;m not sure if above Key Fingerprint belongs to %1</source>
        <translation>No estoy seguro si la Huella de la Clave pertenece a %1</translation>
    </message>
    <message>
        <source>I confirm that above Key Fingerprint belongs to %1</source>
        <translation>Confirmo que la Huella de la Clave pertenece a %1</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationProgressPage</name>
    <message>
        <source>Verification Progress</source>
        <translation>Progreso de Verificación</translation>
    </message>
    <message>
        <source>Verification in progres...</source>
        <translation>Verificación en progreso...</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationQuestionAndAnswerPage</name>
    <message>
        <source>Ask Question</source>
        <translation>Hacer pregunta</translation>
    </message>
    <message>
        <source>Question and Answer</source>
        <translation>Pregunta y Respuesta</translation>
    </message>
    <message>
        <source>Question that only %1 can answer:</source>
        <translation>Pregunta que sólo %1 puede responder:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Respuesta:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationRespondQuestionAndAnswerPage</name>
    <message>
        <source>Answer Question</source>
        <translation>Contestar pregunta</translation>
    </message>
    <message>
        <source>Respond to Question and Answer</source>
        <translation>Responder a Pregunta y Respuesta</translation>
    </message>
    <message>
        <source>%1 wants to verify your identity using Question and Answer method.</source>
        <translation>%1 quiere verificar su identidad usando el método de Pregunta y Respuesta.</translation>
    </message>
    <message>
        <source>%1 question:</source>
        <translation>%1 pregunta:</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Respuesta:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationRespondSharedSecretPage</name>
    <message>
        <source>Send Shared Secret</source>
        <translation>Enviar secreto compartido</translation>
    </message>
    <message>
        <source>Respond to Shared Secret</source>
        <translation>Responder al secreto compartido</translation>
    </message>
    <message>
        <source>%1 wants to verify your identity using Shared Secret method.</source>
        <translation>%1 quiere verificar su identidad usando el método de Secreto Compartido.</translation>
    </message>
    <message>
        <source>Shared Secret that is known only for you and %1:</source>
        <translation>Secreto Compartido que se conoce sólo por usted y %1:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationResultPage</name>
    <message>
        <source>Verification Result</source>
        <translation>Resultado de verificación</translation>
    </message>
    <message>
        <source>Verificationof %1 failed. You are probably talking to an imposter. Either close conversation or try other verification method.</source>
        <translation>La verificación de %1 falló. Usted probablemente está hablando con un impostor. Cierre la conversación o intente otro método de verificación.</translation>
    </message>
    <message>
        <source>%1 has verified you. You should do the same.</source>
        <translation>%1 te ha verificado. Usted debe hacer lo mismo.</translation>
    </message>
    <message>
        <source>Verification of %1 succeeded.</source>
        <translation>La verificación de %1 tuvo éxito.</translation>
    </message>
    <message>
        <source>Unknown.</source>
        <translation>Desconocido.</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationSelectMethodPage</name>
    <message>
        <source>Select Verification Method</source>
        <translation>Seleccionar método de verificación</translation>
    </message>
    <message>
        <source>Question and Answer</source>
        <translation>Pregunta y Respuesta</translation>
    </message>
    <message>
        <source>Shared Secred</source>
        <translation>Secreto compartido</translation>
    </message>
    <message>
        <source>Fingerprint Exchange</source>
        <translation>Intercambio de Huella</translation>
    </message>
    <message>
        <source>Ask peer a question that only you and he/she know the answer for. If your peer answer it properly, he/she will be marked as verified.</source>
        <translation>Hacer una pregunta al par que sólo usted y él/ella conocen la respuesta. Si su par la responde correctamente, él/ella estará marcado como verificado.</translation>
    </message>
    <message>
        <source>Exchange a secret message with peer. This message should be agreed to on another secure channel (face-to-face conversation or a phone).</source>
        <translation>Intercambiar un mensaje secreto con el par. Este mensaje debe ser acordado en otro canal seguro (conversación cara a cara o por teléfono).</translation>
    </message>
    <message>
        <source>Check your peer&apos;s fingerprint manually. Fingreprint information shoud be exchanged on another secure channel (face-to-face conversation or a phone).</source>
        <translation>Compruebe la huella de su par manualmente. La informacion de la huella debe ser intercambiada en otro canal seguro (conversación cara a cara o por teléfono).</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationSharedSecretPage</name>
    <message>
        <source>Ask for Shared Secret</source>
        <translation>Solicitar Secreto Compartido</translation>
    </message>
    <message>
        <source>Shared Secret</source>
        <translation>Secreto Compartido</translation>
    </message>
    <message>
        <source>Shared Secret that is known only for you and %1:</source>
        <translation>Secreto Compartido que se conoce sólo por usted y %1:</translation>
    </message>
</context>
<context>
    <name>OtrPeerIdentityVerificationWindow</name>
    <message>
        <source>Verify Identity of %1</source>
        <translation>Verificar la Identidad de %1</translation>
    </message>
</context>
<context>
    <name>OtrPluginObject</name>
    <message>
        <source>OTR encryption library could not be initialized</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
